{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "qiime2: Demultiplex paired-end sequence data for data generated with the Earth Microbiome Project (EMP) amplicon sequencing protocol",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "qiime2/core:2018.4",
                    "id": "#qiime2-docker-hint.yml",
                    "name": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "label": "Column from metadata file or artifact viewable as metadata",
                    "inputBinding": {
                        "prefix": "--m-barcodes-column"
                    },
                    "id": "#demux-emp-paired.cwl/barcodes_column"
                },
                {
                    "type": "File",
                    "label": "Metadata file or artifact viewable as metadata",
                    "inputBinding": {
                        "prefix": "--m-barcodes-file"
                    },
                    "id": "#demux-emp-paired.cwl/barcodes_file"
                },
                {
                    "type": "string",
                    "label": "Filename for the resulting demultiplexed sequences",
                    "inputBinding": {
                        "prefix": "--o-per-sample-sequences"
                    },
                    "id": "#demux-emp-paired.cwl/per_sample_sequences_filename"
                },
                {
                    "type": "boolean",
                    "label": "the barcode sequences in the sample metadata will be reverse complement prior to demultiplexing",
                    "inputBinding": {
                        "prefix": "--p-rev-comp-mapping-barcodes"
                    },
                    "id": "#demux-emp-paired.cwl/rev_comp_mapping_barcodes"
                },
                {
                    "type": "File",
                    "label": "qiime2 artifact file with formats (EMPPairedEndSequences | EMPSingleEndSequences | RawSequences)",
                    "inputBinding": {
                        "prefix": "--i-seqs"
                    },
                    "id": "#demux-emp-paired.cwl/seqs"
                }
            ],
            "baseCommand": [
                "qiime",
                "demux",
                "emp-paired"
            ],
            "id": "#demux-emp-paired.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.per_sample_sequences_filename)"
                    },
                    "id": "#demux-emp-paired.cwl/demux_sequences_artifact"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "qiime2: Summarize counts per sample for all samples, and generate interactive positional quality plots based on `n` randomly selected sequences",
            "hints": [
                {
                    "$import": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "de-multiplexed sequences to be summarized",
                    "inputBinding": {
                        "prefix": "--i-data"
                    },
                    "id": "#demux-summarize.cwl/data"
                },
                {
                    "type": "string",
                    "label": "filename for the resulting visualization file",
                    "inputBinding": {
                        "prefix": "--o-visualization"
                    },
                    "id": "#demux-summarize.cwl/visualization_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.visualization_filename)"
                    },
                    "id": "#demux-summarize.cwl/demux_visualization_artifact"
                }
            ],
            "baseCommand": [
                "qiime",
                "demux",
                "summarize"
            ],
            "id": "#demux-summarize.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "label": "qiime2 demux paired sequences",
            "inputs": [
                {
                    "type": "string",
                    "default": "demux.qza",
                    "id": "#main/demux_sequences_filename"
                },
                {
                    "type": "string",
                    "default": "demux.qzv",
                    "id": "#main/demux_visualization_filename"
                },
                {
                    "type": "string",
                    "id": "#main/metadata_barcodes_column"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "id": "#main/rev_comp_mapping_barcodes"
                },
                {
                    "type": "File",
                    "id": "#main/sample_metadata"
                },
                {
                    "type": "File",
                    "id": "#main/sequences_artifact"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/demux_sequences/demux_sequences_artifact",
                    "id": "#main/demux_sequences_artifact"
                },
                {
                    "type": "File",
                    "outputSource": "#main/demux_visualization/demux_visualization_artifact",
                    "id": "#main/demux_visualization_artifact"
                }
            ],
            "steps": [
                {
                    "run": "#demux-emp-paired.cwl",
                    "in": [
                        {
                            "source": "#main/metadata_barcodes_column",
                            "id": "#main/demux_sequences/barcodes_column"
                        },
                        {
                            "source": "#main/sample_metadata",
                            "id": "#main/demux_sequences/barcodes_file"
                        },
                        {
                            "source": "#main/demux_sequences_filename",
                            "id": "#main/demux_sequences/per_sample_sequences_filename"
                        },
                        {
                            "source": "#main/rev_comp_mapping_barcodes",
                            "id": "#main/demux_sequences/rev_comp_mapping_barcodes"
                        },
                        {
                            "source": "#main/sequences_artifact",
                            "id": "#main/demux_sequences/seqs"
                        }
                    ],
                    "out": [
                        "#main/demux_sequences/demux_sequences_artifact"
                    ],
                    "id": "#main/demux_sequences"
                },
                {
                    "run": "#demux-summarize.cwl",
                    "in": [
                        {
                            "source": "#main/demux_sequences/demux_sequences_artifact",
                            "id": "#main/demux_visualization/data"
                        },
                        {
                            "source": "#main/demux_visualization_filename",
                            "id": "#main/demux_visualization/visualization_filename"
                        }
                    ],
                    "out": [
                        "#main/demux_visualization/demux_visualization_artifact"
                    ],
                    "id": "#main/demux_visualization"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
